@@ -15,11 +15,9 @@
 
 
 from neutron_lib import constants as n_const
+from neutron_lib.plugins import utils as p_utils
 from oslo_log import log as logging
 
-from neutron.db import api as db_api
-from neutron.plugins.common import utils as p_utils
-
 
 LOG = logging.getLogger(__name__)
 OPENDAYLIGHT_DEVICE_ID = 'OpenDaylight'
@@ -31,7 +29,6 @@ class OdlDhcpDriverBase(object):
     # of enable_dhcp in case of subnet update event, instead validating on
     # port_id presence in DB by locking the session, this will enable user to
     # reissue the same command in case of failure.
-    @db_api.retry_db_errors
     def create_or_delete_dhcp_port(self, subnet_context):
         # NOTE:(Achuth) Fixes bug 1746715
         # DHCP port to be created for IPv4 subnets only, since ODL doesn't
@@ -48,11 +45,11 @@ class OdlDhcpDriverBase(object):
                       subnet_context.current['id'],
                       subnet_context.current['network_id'])
             port = self._make_dhcp_port_dict(subnet_context)
+            # TODO(boden): rehome and consume from neutron-lib
             p_utils.create_port(plugin, subnet_context._plugin_context, port)
         if port_id and not subnet_context.current['enable_dhcp']:
             self._delete_port(plugin, subnet_context._plugin_context, port_id)
 
-    @db_api.retry_db_errors
     def _delete_port(self, plugin, context, port_id):
         LOG.debug("Deleting ODL DHCP port with id %s", port_id)
         plugin.delete_port(context, port_id)
@@ -71,7 +68,6 @@ class OdlDhcpDriverBase(object):
 
         return {'port': port_dict}
 
-    @db_api.retry_db_errors
     def get_dhcp_port_if_exists(self, subnet_context):
 
         plugin = subnet_context._plugin
