@@ -14,6 +14,7 @@
 #    under the License.
 
 import abc
+
 import six
 import stevedore
 
@@ -21,8 +22,6 @@ from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import excutils
 
-from networking_odl._i18n import _LI, _LE
-
 
 LOG = log.getLogger(__name__)
 
@@ -30,6 +29,9 @@ LOG = log.getLogger(__name__)
 @six.add_metaclass(abc.ABCMeta)
 class PortBindingController(object):
 
+    def get_workers(self):
+        return []
+
     @abc.abstractmethod
     def bind_port(self, port_context):
         """Attempt to bind a port.
@@ -97,11 +99,14 @@ class PortBindingManager(PortBindingController):
         if isinstance(extension.obj, PortBindingController):
             return cls(extension.name, extension.obj)
         else:
-            raise ValueError(
-                ("Port binding controller '%(name)s (%(controller)r)' "
-                 "doesn't implement PortBindingController interface."),
+            raise ValueError(_(
+                "Port binding controller '%(name)s (%(controller)r)' "
+                "doesn't implement PortBindingController interface."),
                 {'name': extension.name, 'controller': extension.obj})
 
+    def get_workers(self):
+        return self.controller.get_workers()
+
     def bind_port(self, port_context):
         controller_details = {'name': self.name, 'controller': self.controller}
         try:
@@ -109,13 +114,13 @@ class PortBindingManager(PortBindingController):
         except Exception:
             with excutils.save_and_reraise_exception():
                 LOG.exception(
-                    _LE("Controller '%(name)s (%(controller)r)' had an error "
-                        "when binding port."), controller_details)
+                    "Controller '%(name)s (%(controller)r)' had an error "
+                    "when binding port.", controller_details)
         else:
             if port_context._new_bound_segment:
                 LOG.info(
-                    _LI("Controller '%(name)s (%(controller)r)' has bound "
-                        "port."), controller_details)
+                    "Controller '%(name)s (%(controller)r)' has bound port.",
+                    controller_details)
             else:
                 LOG.debug(
                     "Controller %(name)s (%(controller)r) hasn't bound "
