@@ -13,16 +13,28 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_log import helpers as log_helpers
 from oslo_log import log as logging
 
+from networking_sfc.extensions import sfc as sfc_const
 from networking_sfc.services.sfc.drivers import base as sfc_driver
 
 from networking_odl.common import constants as odl_const
+from networking_odl.common import postcommit
+from networking_odl.journal import full_sync
 from networking_odl.journal import journal
 
 LOG = logging.getLogger(__name__)
 
+SFC_RESOURCES = {
+    odl_const.ODL_SFC_PORT_PAIR: odl_const.NETWORKING_SFC_PORT_PAIRS,
+    odl_const.ODL_SFC_PORT_PAIR_GROUP:
+        odl_const.NETWORKING_SFC_PORT_PAIR_GROUPS,
+    odl_const.ODL_SFC_PORT_CHAIN: odl_const.NETWORKING_SFC_PORT_CHAINS
+}
 
+
+@postcommit.add_postcommit('port_pair', 'port_pair_group', 'port_chain')
 class OpenDaylightSFCDriverV2(sfc_driver.SfcDriverBase):
     """OpenDaylight SFC Driver (Version 2) for networking-sfc.
 
@@ -34,92 +46,98 @@ class OpenDaylightSFCDriverV2(sfc_driver.SfcDriverBase):
 
     def initialize(self):
         LOG.debug("Initializing OpenDaylight Networking SFC driver(Version 2)")
-        self.journal = journal.OpendaylightJournalThread()
+        self.journal = journal.OpenDaylightJournalThread()
+        full_sync.register(sfc_const.SFC_EXT, SFC_RESOURCES)
 
     @staticmethod
     def _record_in_journal(context, object_type, operation, data=None):
         if data is None:
             data = context.current
-        journal.record(context._plugin_context, context, object_type,
+        journal.record(context._plugin_context, object_type,
                        context.current['id'], operation, data)
 
+    @log_helpers.log_method_call
     def create_port_pair_precommit(self, context):
         OpenDaylightSFCDriverV2._record_in_journal(
             context, odl_const.ODL_SFC_PORT_PAIR, odl_const.ODL_CREATE)
 
+    @log_helpers.log_method_call
     def create_port_pair_group_precommit(self, context):
         OpenDaylightSFCDriverV2._record_in_journal(
             context, odl_const.ODL_SFC_PORT_PAIR_GROUP, odl_const.ODL_CREATE)
 
+    @log_helpers.log_method_call
     def create_port_chain_precommit(self, context):
         OpenDaylightSFCDriverV2._record_in_journal(
             context, odl_const.ODL_SFC_PORT_CHAIN, odl_const.ODL_CREATE)
 
+    @log_helpers.log_method_call
     def update_port_pair_precommit(self, context):
         OpenDaylightSFCDriverV2._record_in_journal(
             context, odl_const.ODL_SFC_PORT_PAIR, odl_const.ODL_UPDATE)
 
+    @log_helpers.log_method_call
     def update_port_pair_group_precommit(self, context):
         OpenDaylightSFCDriverV2._record_in_journal(
             context, odl_const.ODL_SFC_PORT_PAIR_GROUP, odl_const.ODL_UPDATE)
 
+    @log_helpers.log_method_call
     def update_port_chain_precommit(self, context):
         OpenDaylightSFCDriverV2._record_in_journal(
             context, odl_const.ODL_SFC_PORT_CHAIN, odl_const.ODL_UPDATE)
 
+    @log_helpers.log_method_call
     def delete_port_pair_precommit(self, context):
         OpenDaylightSFCDriverV2._record_in_journal(
             context, odl_const.ODL_SFC_PORT_PAIR, odl_const.ODL_DELETE,
             data=[])
 
+    @log_helpers.log_method_call
     def delete_port_pair_group_precommit(self, context):
         OpenDaylightSFCDriverV2._record_in_journal(
             context, odl_const.ODL_SFC_PORT_PAIR_GROUP, odl_const.ODL_DELETE,
             data=[])
 
+    @log_helpers.log_method_call
     def delete_port_chain_precommit(self, context):
         OpenDaylightSFCDriverV2._record_in_journal(
             context, odl_const.ODL_SFC_PORT_CHAIN, odl_const.ODL_DELETE,
             data=[])
 
-    def _postcommit(self, context):
-        self.journal.set_sync_event()
-
-    create_port_pair_postcommit = _postcommit
-    create_port_pair_group_postcommit = _postcommit
-    create_port_chain_postcommit = _postcommit
-    update_port_pair_postcommit = _postcommit
-    update_port_pair_group_postcommit = _postcommit
-    update_port_chain_postcommit = _postcommit
-    delete_port_pair_postcommit = _postcommit
-    delete_port_pair_group_postcommit = _postcommit
-    delete_port_chain_postcommit = _postcommit
-
     # Need to implement these methods, else driver loading fails with error
     # complaining about no abstract method implementation present.
+    @log_helpers.log_method_call
     def create_port_pair(self, context):
         super(OpenDaylightSFCDriverV2, self).create_port_pair(context)
 
+    @log_helpers.log_method_call
     def create_port_pair_group(self, context):
         super(OpenDaylightSFCDriverV2, self).create_port_pair_group(context)
 
+    @log_helpers.log_method_call
     def create_port_chain(self, context):
         super(OpenDaylightSFCDriverV2, self).create_port_chain(context)
 
+    @log_helpers.log_method_call
     def update_port_pair(self, context):
         super(OpenDaylightSFCDriverV2, self).update_port_pair(context)
 
+    @log_helpers.log_method_call
     def update_port_pair_group(self, context):
         super(OpenDaylightSFCDriverV2, self).update_port_pair_group(context)
 
+    @log_helpers.log_method_call
     def update_port_chain(self, context):
         super(OpenDaylightSFCDriverV2, self).update_port_chain(context)
 
+    @log_helpers.log_method_call
     def delete_port_pair(self, context):
         super(OpenDaylightSFCDriverV2, self).delete_port_pair(context)
 
+    @log_helpers.log_method_call
     def delete_port_pair_group(self, context):
         super(OpenDaylightSFCDriverV2, self).delete_port_pair_group(context)
 
+    @log_helpers.log_method_call
     def delete_port_chain(self, context):
         super(OpenDaylightSFCDriverV2, self).delete_port_chain(context)
