@@ -18,6 +18,7 @@ import threading
 
 import mock
 from neutron.common import utils
+from neutron_lib import context
 
 from networking_odl.common import constants as odl_const
 from networking_odl.db import db
@@ -27,7 +28,7 @@ from networking_odl.tests.unit import test_base_db
 
 
 TEST_TASK_NAME = 'test-maintenance'
-TEST_TASK_INTERVAL = 0
+TEST_TASK_INTERVAL = 0.1
 
 
 class PeriodicTaskThreadTestCase(test_base_db.ODLBaseDbTestCase):
@@ -35,8 +36,8 @@ class PeriodicTaskThreadTestCase(test_base_db.ODLBaseDbTestCase):
         super(PeriodicTaskThreadTestCase, self).setUp()
         row = models.OpenDaylightPeriodicTask(task=TEST_TASK_NAME,
                                               state=odl_const.PENDING)
-        self.db_session.add(row)
-        self.db_session.flush()
+        self.db_context.session.add(row)
+        self.db_context.session.flush()
 
         self.thread = periodic_task.PeriodicTask(TEST_TASK_NAME,
                                                  TEST_TASK_INTERVAL)
@@ -61,16 +62,15 @@ class PeriodicTaskThreadTestCase(test_base_db.ODLBaseDbTestCase):
 
     def test_thread_works(self):
         callback_event = threading.Event()
-        # TODO(mpeterson): Make this an int when Py2 is no longer supported
-        # and use the `nonlocal` directive
-        count = [0]
+        count = 0
 
-        def callback_op(**kwargs):
-            count[0] += 1
+        def callback_op(*args):
+            nonlocal count
+            count += 1
 
             # The following should be true on the second call, so we're making
             # sure that the thread runs more than once.
-            if count[0] > 1:
+            if count > 1:
                 callback_event.set()
 
         self.thread.register_operation(callback_op)
@@ -83,12 +83,12 @@ class PeriodicTaskThreadTestCase(test_base_db.ODLBaseDbTestCase):
         exception_event = threading.Event()
         callback_event = threading.Event()
 
-        def exception_op(**kwargs):
+        def exception_op(*args):
             if not exception_event.is_set():
                 exception_event.set()
                 raise Exception()
 
-        def callback_op(**kwargs):
+        def callback_op(*args):
             callback_event.set()
 
         for op in [exception_op, callback_op]:
@@ -106,10 +106,10 @@ class PeriodicTaskThreadTestCase(test_base_db.ODLBaseDbTestCase):
         callback_event1 = threading.Event()
         self.addCleanup(self.thread1.cleanup)
 
-        def callback_op(**kwargs):
+        def callback_op(*args):
             callback_event.set()
 
-        def callback_op1(**kwargs):
+        def callback_op1(*args):
             callback_event1.set()
 
         self.thread.register_operation(callback_op)
@@ -125,7 +125,7 @@ class PeriodicTaskThreadTestCase(test_base_db.ODLBaseDbTestCase):
         callback_event = threading.Event()
         continue_event = threading.Event()
 
-        def callback_op(**kwargs):
+        def callback_op(*args):
             callback_event.set()
 
         return_value = True
@@ -152,49 +152,46 @@ class PeriodicTaskThreadTestCase(test_base_db.ODLBaseDbTestCase):
 
     def test_set_operation_retries_exceptions(self):
         with mock.patch.object(db, 'update_periodic_task') as m:
-            self._test_retry_exceptions(self.thread._set_operation,
-                                        m, True)
+            self._test_retry_exceptions(self.thread._set_operation, m)
 
     def test_lock_task_retries_exceptions(self):
         with mock.patch.object(db, 'lock_periodic_task') as m:
-            self._test_retry_exceptions(self.thread._lock_task,
-                                        m, True)
+            self._test_retry_exceptions(self.thread._lock_task, m)
 
     def test_clear_and_unlock_task_retries_exceptions(self):
         with mock.patch.object(db, 'update_periodic_task') as m:
-            self._test_retry_exceptions(self.thread._clear_and_unlock_task,
-                                        m, True)
+            self._test_retry_exceptions(self.thread._clear_and_unlock_task, m)
 
     @mock.patch.object(db, "was_periodic_task_executed_recently",
                        return_value=False)
     def test_no_multiple_executions_simultaneously(self, mock_exec_recently):
         continue_event = threading.Event()
         trigger_event = threading.Event()
-        # TODO(mpeterson): Make this an int when Py2 is no longer supported
-        # and use the `nonlocal` directive
-        count = [0]
+        count = 0
 
         def wait_until_event(context):
+            nonlocal count
             trigger_event.set()
             if continue_event.wait(2):
-                count[0] += 1
+                count += 1
 
         self.thread.register_operation(wait_until_event)
 
         def task_locked():
-            row = (self.db_session.query(models.OpenDaylightPeriodicTask)
-                                  .filter_by(state=odl_const.PROCESSING,
-                                             task=TEST_TASK_NAME)
-                                  .one_or_none())
+            session = self.db_context.session
+            row = (session.query(models.OpenDaylightPeriodicTask)
+                          .filter_by(state=odl_const.PROCESSING,
+                                     task=TEST_TASK_NAME)
+                          .one_or_none())
             return (row is not None)
 
         self.thread.start()
         utils.wait_until_true(trigger_event.is_set, 5, 0.01)
-        self.assertEqual(count[0], 0)
+        self.assertEqual(count, 0)
         self.assertTrue(task_locked())
 
         self.thread.execute_ops()
-        self.assertEqual(count[0], 0)
+        self.assertEqual(count, 0)
         self.assertTrue(task_locked())
 
         continue_event.set()
@@ -202,7 +199,7 @@ class PeriodicTaskThreadTestCase(test_base_db.ODLBaseDbTestCase):
         utils.wait_until_true(trigger_event.is_set, 5, 0.01)
         self.thread.cleanup()
         self.assertFalse(task_locked())
-        self.assertGreaterEqual(count[0], 1)
+        self.assertGreaterEqual(count, 1)
 
     @mock.patch.object(db, "was_periodic_task_executed_recently",
                        return_value=True)
@@ -214,3 +211,20 @@ class PeriodicTaskThreadTestCase(test_base_db.ODLBaseDbTestCase):
         self.thread.execute_ops(forced=True)
 
         operation.assert_called()
+
+    @mock.patch.object(db, "was_periodic_task_executed_recently",
+                       return_value=True)
+    def test_context_is_passed_as_args(self, _):
+        operation = mock.MagicMock()
+        operation.__name__ = 'test'
+        self.thread.register_operation(operation)
+
+        self.thread.execute_ops(forced=True)
+
+        # This tests that only ONE args is passed, and no kwargs
+        operation.assert_called_with(mock.ANY)
+
+        # This tests that it's a context
+        kall = operation.call_args
+        args, kwargs = kall
+        self.assertIsInstance(args[0], context.Context)
