@@ -28,6 +28,7 @@ from networking_odl.journal import recovery
 from networking_odl.l3 import l3_odl_v2
 from networking_odl.ml2 import mech_driver_v2
 from networking_odl.tests import base
+from networking_odl.tests.unit.db import test_db
 from networking_odl.tests.unit.journal import helper
 from networking_odl.tests.unit import test_base_db
 
@@ -54,7 +55,7 @@ class RecoveryTestCase(test_base_db.ODLBaseDbTestCase):
         return mock.MagicMock(object_type=resource_type)
 
     def _test__get_latest_resource(self, plugin, resource_type):
-        l2 = mech_driver_v2.L2_RESOURCES
+        l2 = mech_driver_v2.OpenDaylightMechanismDriver.RESOURCES
         full_sync.ALL_RESOURCES[plugin_constants.CORE] = l2
         mock_resource = self._mock_resource(plugin, resource_type)
         mock_row = self._mock_row(resource_type)
@@ -65,7 +66,9 @@ class RecoveryTestCase(test_base_db.ODLBaseDbTestCase):
 
     @mock.patch.object(directory, 'get_plugin')
     def test__get_latest_resource_l2(self, plugin_mock):
-        for resource_type in mech_driver_v2.L2_RESOURCES:
+        for resource_type in(
+                mech_driver_v2.OpenDaylightMechanismDriver.RESOURCES):
+
             plugin = plugin_mock.return_value
             self._test__get_latest_resource(plugin, resource_type)
 
@@ -85,7 +88,7 @@ class RecoveryTestCase(test_base_db.ODLBaseDbTestCase):
     @mock.patch.object(directory, 'get_plugin')
     def test__get_latest_resource_none(self, plugin_mock):
         plugin_mock.return_value.get_network.side_effect = nexc.NotFound()
-        l2 = mech_driver_v2.L2_RESOURCES
+        l2 = mech_driver_v2.OpenDaylightMechanismDriver.RESOURCES
         full_sync.ALL_RESOURCES[plugin_constants.CORE] = l2
 
         mock_row = self._mock_row(odl_const.ODL_NETWORK)
@@ -94,24 +97,24 @@ class RecoveryTestCase(test_base_db.ODLBaseDbTestCase):
             self.db_context.session, mock_row)
 
     def test_journal_recovery_retries_exceptions(self):
-        db.create_pending_row(self.db_context.session, odl_const.ODL_NETWORK,
+        db.create_pending_row(self.db_context, odl_const.ODL_NETWORK,
                               'id', odl_const.ODL_DELETE, {})
-        created_row = db.get_all_db_rows(self.db_context.session)[0]
-        db.update_db_row_state(self.db_context.session, created_row,
+        created_row = db.get_all_db_rows(self.db_context)[0]
+        db.update_db_row_state(self.db_context, created_row,
                                odl_const.FAILED)
         with mock.patch.object(db, 'update_db_row_state') as m:
-            self._test_retry_exceptions(recovery.journal_recovery, m, True)
+            self._test_retry_exceptions(recovery.journal_recovery, m)
 
     def test_journal_recovery_no_rows(self):
         recovery.journal_recovery(self.db_context)
         self.assertFalse(self._CLIENT.get_resource.called)
 
+    @test_db.in_session
     def _test_recovery(self, operation, odl_resource, expected_state):
-        db.create_pending_row(self.db_context.session, odl_const.ODL_NETWORK,
+        db.create_pending_row(self.db_context, odl_const.ODL_NETWORK,
                               'id', operation, {})
-        created_row = db.get_all_db_rows(self.db_context.session)[0]
-        db.update_db_row_state(self.db_context.session, created_row,
-                               odl_const.FAILED)
+        created_row = db.get_all_db_rows(self.db_context)[0]
+        db.update_db_row_state(self.db_context, created_row, odl_const.FAILED)
 
         self._CLIENT.get_resource.return_value = odl_resource
 
@@ -119,10 +122,10 @@ class RecoveryTestCase(test_base_db.ODLBaseDbTestCase):
 
         if expected_state is None:
             completed_rows = db.get_all_db_rows_by_state(
-                self.db_context.session, odl_const.COMPLETED)
+                self.db_context, odl_const.COMPLETED)
             self.assertEqual([], completed_rows)
         else:
-            row = db.get_all_db_rows_by_state(self.db_context.session,
+            row = db.get_all_db_rows_by_state(self.db_context,
                                               expected_state)[0]
             self.assertEqual(created_row['seqnum'], row['seqnum'])
 
@@ -168,7 +171,7 @@ class RecoveryTestCase(test_base_db.ODLBaseDbTestCase):
             operation, odl_resource, odl_const.COMPLETED)
 
         pending_row = db.get_all_db_rows_by_state(
-            self.db_context.session, odl_const.PENDING)[0]
+            self.db_context, odl_const.PENDING)[0]
         self.assertEqual(expected_operation, pending_row['operation'])
         self.assertEqual(original_row['object_type'],
                          pending_row['object_type'])
@@ -217,7 +220,7 @@ class RecoveryTestCase(test_base_db.ODLBaseDbTestCase):
         helper.TestDriver()
         directory.add_plugin(helper.TEST_PLUGIN, helper.TestPlugin())
         self.addCleanup(directory.add_plugin, helper.TEST_PLUGIN, None)
-        return db.create_pending_row(self.db_context.session, resource_type,
+        return db.create_pending_row(self.db_context, resource_type,
                                      'id', odl_const.ODL_DELETE, {})
 
     def test_get_latest_resource(self):
